/* Abstraction of various C++ ABI's we support, and the info we need
   to get from them.
   Contributed by Daniel Berlin <dberlin@redhat.com>
   Copyright 2001 Free Software Foundation, Inc.

   This file is part of GDB.

   This program is free software; you can redistribute it and/or
   modify
   it under the terms of the GNU General Public License as published
   by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

#ifndef CP_ABI_H_
#define CP_ABI_H_ 1

/* Following the target ops as a reference */
struct cp_abi_ops
{
  const char *cpo_shortname;
  const char *cpo_longname;
  const char *cpo_doc;


  /* FIXME: prefix is a misnomer, because not all ABI's do
     constructors by prefix. However, we don't want these names to be
     not understandable, and ca_mangled_name_is_constructor_p is a
     little long. Ideas?
  */
  /* Determine if the given *mangled* name is a destructor. Might
  change to demangled name in the future, but not without warning. It
  depends on whether or not this ends up being completely used in the
  old GNU abi, or if it was really needed somewhere else */
  
  int (*cpo_destructor_prefix_p) (const char *name); 
  
  /* Determine if a given *mangled* name is a constructor. Same
     warning as for destructor functions.*/
  int (*cpo_constructor_prefix_p) (const char *name);

  /* Determine if a given *mangled* name is a vtable. Same warning as
     for constructors and destructor functions. */
  int (*cpo_vtable_prefix_p) (const char *name);

  /* Determine if a given *mangled* name is an operator. Same warning
     as all of the others */
  int (*cpo_operator_prefix_p) (const char *name);
};

extern struct cp_abi_ops current_cp_abi;

#define constructor_prefix_p(NAME) \
(*current_cp_abi.cpo_constructor_prefix_p)(NAME)

#define destructor_prefix_p(NAME) \
(*current_cp_abi.cpo_destructor_prefix_p)(NAME)

#define vtbl_prefix_p(NAME) \
(*current_cp_abi.cpo_vtable_prefix_p)(NAME)

#define operator_prefix_p(NAME) \
(*current_cp_abi.cpo_operator_prefix_p)(NAME)
#endif

