/* Abstraction of GNU v2 abi.
   Contributed by Daniel Berlin <dberlin@redhat.com>
   Copyright 2001 Free Software Foundation, Inc.

   This file is part of GDB.

   This program is free software; you can redistribute it and/or
   modify
   it under the terms of the GNU General Public License as published
   by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

#include "defs.h"
#include "cp-abi.h"
#include "gdb_regex.h"
#include "gdb_string.h"
#include <ctype.h>

struct cp_abi_ops gnu_v2_abi_ops;

int gnuv2_destructor_prefix_p (const char * name)
{
  return ((name[0] == '_' && is_cplus_marker (name[1]) && name[2] == '_')  
	  || strncmp(name, "__dt__", 6) == 0);
}

int gnuv2_constructor_prefix_p (const char * name)
{ 
  return ((name[0] == '_' && name[1] == '_'  
	   && (isdigit (name[2]) || strchr ("Qt", name[2]))) 
	  || strncmp(name, "__ct__", 6) == 0);
}

int gnuv2_vtable_prefix_p (const char * name)
{
  return (((name)[0] == '_' 
	   && (((name)[1] == 'V' && (name)[2] == 'T') 
	       ||  ((name)[1] == 'v' && (name)[2] == 't'))
	   && is_cplus_marker ((name)[3])) || 
	  ((name)[0] == '_' && (name)[1] == '_' 
	   && (name)[2] == 'v' && (name)[3] == 't' && (name)[4] == '_'));
}

void
init_gnuv2_ops (void)
{
  gnu_v2_abi_ops.cpo_shortname = "gnu-v2";
  gnu_v2_abi_ops.cpo_longname = "GNU G++ Version 2 ABI";
  gnu_v2_abi_ops.cpo_doc = "G++ Version 2 ABI";
  gnu_v2_abi_ops.cpo_destructor_prefix_p = gnuv2_destructor_prefix_p;
  gnu_v2_abi_ops.cpo_constructor_prefix_p = gnuv2_constructor_prefix_p;
  gnu_v2_abi_ops.cpo_vtable_prefix_p = gnuv2_vtable_prefix_p;
  

}
struct cp_abi_ops current_cp_abi;
void
_initialize_gnu_v2_abi (void)
{
  init_gnuv2_ops();
  current_cp_abi = gnu_v2_abi_ops;
  
}

